Module catalog

Module catalog 

Catalog Schema and Catalog Items diff. See IMPLEMENTATION.md 11.1 / 11.2.

Structs

CatalogItemsDiff
CatalogSchemaDiff

Functions

diff_items
Diff catalog items by comparing their content hashes. Only the hash maps are needed — the actual row data is not loaded or compared.
diff_schema
Diff a catalog schema between local intent and remote (Braze) state.