pub struct PlanFile {
pub version: u32,
pub generated_at: DateTime<Utc>,
pub braze_sync_version: String,
pub scope: PlanScope,
pub ops: Vec<PlanOp>,
}Fields
version: u32generated_at: DateTime<Utc>braze_sync_version: Stringscope: PlanScopeops: Vec<PlanOp>Implementations
Sourceimpl PlanFile
impl PlanFile
pub fn from_summary( summary: &DiffSummary, environment: impl Into<String>, resource: Option<ResourceKind>, name: Option<String>, archive_orphans: bool, ) -> Self
pub fn read_from(path: &Path) -> Result<Self>
pub fn write_to(&self, path: &Path) -> Result<()>
Sourcepub fn diff_ops(&self, fresh: &[PlanOp]) -> PlanOpsDiff
pub fn diff_ops(&self, fresh: &[PlanOp]) -> PlanOpsDiff
Compare saved ops against fresh as a multiset over (kind, name, op_type), order-independent. collect_ops is invariant-by-design
unique per (kind, name) today, but we use a merge walk rather
than a set so duplicates would surface as drift instead of being
silently collapsed.