pub struct PlanScope {
pub environment: String,
pub resource: Option<ResourceKind>,
pub name: Option<String>,
pub archive_orphans: bool,
}Fields
environment: Stringresource: Option<ResourceKind>name: Option<String>archive_orphans: boolWhether the plan was generated with the intent to archive orphans
at apply time. Orphan ops only actually write when apply --archive-orphans is set, so the apply flag must match the plan
scope or the frozen op set would not reflect the real write set.