pub struct ResolutionFailure {
pub resource_kind: &'static str,
pub resource_name: String,
pub field: Option<&'static str>,
pub errors: Vec<ResolutionError>,
}Expand description
One resource’s worth of placeholder failures, ready to be folded into a top-level error message.
Fields
resource_kind: &'static strresource_name: Stringfield: Option<&'static str>Some(field) for email_template fields, None for content_block.
errors: Vec<ResolutionError>Trait Implementations
Sourceimpl Clone for ResolutionFailure
impl Clone for ResolutionFailure
Sourcefn clone(&self) -> ResolutionFailure
fn clone(&self) -> ResolutionFailure
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResolutionFailure
impl Debug for ResolutionFailure
Sourceimpl PartialEq for ResolutionFailure
impl PartialEq for ResolutionFailure
Sourcefn eq(&self, other: &ResolutionFailure) -> bool
fn eq(&self, other: &ResolutionFailure) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ResolutionFailure
impl StructuralPartialEq for ResolutionFailure