Catalog Schema and Catalog Items diff. See IMPLEMENTATION.md 11.1 / 11.2.
Structs
Functions
- diff_
items - Diff catalog items by comparing their content hashes. Only the hash maps are needed — the actual row data is not loaded or compared.
- diff_
schema - Diff a catalog schema between local intent and remote (Braze) state.